IDtoBottomSheet class

Mobile bottom-sheet sizing for displayMode: bottomSheet. minHeight / maxHeight accept a num (px) or a String percentage (e.g. '60%').

Constructors

IDtoBottomSheet({Object? minHeight, Object? maxHeight})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
maxHeight Object?
final
minHeight Object?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited