IDtoNameMatchConfig class

Host-app rules for the silent name_match module.

Constructors

IDtoNameMatchConfig({int? threshold, IDtoNameMatchDecisionMode? decisionMode, List<String>? extraHonorifics, Map<String, String>? aliases, List<IDtoNameMatchPair>? comparePairs})
const

Properties

aliases Map<String, String>?
final
comparePairs List<IDtoNameMatchPair>?
final
decisionMode IDtoNameMatchDecisionMode?
final
extraHonorifics List<String>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
threshold int?
0–100. When set, each pair gets a match bool and an overall passed.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited