IDtoNameMatchPair enum

A name-match comparison pair.

Inheritance
Available extensions

Values

aadhaarVsPan → const IDtoNameMatchPair
const IDtoNameMatchPair('aadhaar_vs_pan')
aadhaarVsDl → const IDtoNameMatchPair
const IDtoNameMatchPair('aadhaar_vs_dl')
aadhaarVsBank → const IDtoNameMatchPair
const IDtoNameMatchPair('aadhaar_vs_bank')
panVsBank → const IDtoNameMatchPair
const IDtoNameMatchPair('pan_vs_bank')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wire String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<IDtoNameMatchPair>
A constant List of the values in this enum, in order of their declaration.