IDto class
Entry point for IDto identity verification.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- guard → IDtoOpenGuard
-
Process-wide concurrent-open guard.
final
Static Methods
-
open(
BuildContext context, {required IDtoConfig config, void onStepComplete(IDtoStepData data)?, void onWorkflowComplete(IDtoWorkflowCompleteData data)?, void onError(IDtoErrorData data)?, void onAbandon(IDtoAbandonData data)?, Future< String> getToken()?, ValueNotifier<int> ? closeSignal}) → Future<IDtoResult> - Opens a full-screen IDto verification flow and returns its terminal result.